---
search:
  exclude: true
---
# 编排多个智能体

编排指的是应用中智能体的流程：哪些智能体运行、以何种顺序运行、以及它们如何决定下一步。编排智能体主要有两种方式：

1. 让 LLM 做决策：利用 LLM 的智能来规划、推理，并据此决定采取哪些步骤。
2. 通过代码进行编排：用你的代码来确定智能体的流程。

你可以混合使用这些模式。每种方式都有取舍，见下文。

## 通过 LLM 编排

一个智能体是配备了 instructions、tools 和 任务转移 的 LLM。这意味着面对开放式任务时，LLM 可以自主规划如何处理任务，使用工具执行操作并获取数据，并通过任务转移将工作委托给子智能体。比如，一个研究智能体可以配备如下工具：

- 网络检索以在线查找信息
- 文件检索与读取以搜索专有数据与连接
- 计算机操作以在计算机上执行操作
- 代码执行以进行数据分析
- 任务转移给擅长规划、报告撰写等的专业化智能体

当任务是开放式且你希望依赖 LLM 的智能时，这种模式非常合适。关键策略包括：

1. 投入高质量提示词。明确可用的工具、使用方式以及必须遵循的参数范围。
2. 监控你的应用并持续迭代。找到问题点，并迭代优化提示词。
3. 允许智能体自省与改进。例如，将其置于循环中，让其自我批判；或提供错误信息并让其改进。
4. 使用在单一任务上表现出色的专业化智能体，而不是期望一个通用智能体在所有任务上都擅长。
5. 投入到[评估（evals）](https://platform.openai.com/docs/guides/evals)。这能帮助你训练智能体以持续改进并更好地完成任务。

## 通过代码编排

虽然通过 LLM 编排很强大，但通过代码编排在速度、成本和性能方面更具确定性和可预测性。常见模式包括：

- 使用 [structured outputs](https://platform.openai.com/docs/guides/structured-outputs) 生成你可以用代码检查的格式良好的数据。例如，你可以让智能体将任务归类到几个目录中，然后基于该目录选择下一个智能体。
- 将多个智能体串联起来，把一个的输出转换为下一个的输入。你可以将“写一篇博文”这样的任务分解为一系列步骤——做研究、写大纲、写正文、批判性审阅，然后改进。
- 使用一个执行任务的智能体与一个负责评估并提供反馈的智能体，在 `while` 循环中运行，直到评估者认为输出满足特定标准。
- 并行运行多个智能体，例如通过 Python 基本组件如 `asyncio.gather`。当你有多个相互独立的任务时，这对提升速度很有用。

我们在 [`examples/agent_patterns`](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns) 中提供了若干代码示例。